<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\Api;

use Locr\WordPress\Plugin\LocrMaps\DDD\ValueObjects\{GeneralOptions, IconOptions, SearchOptions};

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the shortcode.
 */
final class Settings {
	/**
	 * This function registers the all options route.
	 */
	public static function register_all_options_route(): void {
		register_rest_route(
			route_namespace: 'locrmaps/settings',
			route: '/all-options',
			args: array(
				'methods'             => \WP_REST_Server::READABLE,
				'callback'            => function () {
					$general_options = new GeneralOptions();
					$icon_options = new IconOptions();
					return rest_ensure_response(
						array(
							'general' => $general_options->to_array(),
							'icon'    => $icon_options->to_array(),
						)
					);
				},
				'permission_callback' => '__return_true',
			)
		);
	}

	/**
	 * This function registers the general options route.
	 */
	public static function register_general_options_route(): void {
		register_rest_route(
			route_namespace: 'locrmaps/settings',
			route: '/general-options',
			args: array(
				'methods'             => \WP_REST_Server::READABLE,
				'callback'            => function () {
					$general_options = new GeneralOptions();
					return rest_ensure_response( $general_options->to_array() );
				},
				'permission_callback' => '__return_true',
			)
		);
	}

	/**
	 * This function registers the icon options route.
	 */
	public static function register_icon_options_route(): void {
		register_rest_route(
			route_namespace: 'locrmaps/settings',
			route: '/icon-options',
			args: array(
				'methods'             => \WP_REST_Server::READABLE,
				'callback'            => function () {
					$icon_options = new IconOptions();
					return rest_ensure_response( $icon_options->to_array() );
				},
				'permission_callback' => '__return_true',
			)
		);
	}
}
